package
Version:
v0.0.0-...-b66a3fd
Opens a new window with list of versions in this module.
Published: Sep 23, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const ANSWER QaType = "answer"
type Record struct {
QaType QaType `json:"qaType"`
ModelId string `json:"modelId"`
RequestId string `json:"requestId"`
Content string `json:"content"`
}
Init Init 初始化ChargeService服务,并返回错误信息(如果有)
Name func (c Service) Name() string
获取服务名称,实现ChargeService接口的Name方法
Source Files
¶
Click to show internal directories.
Click to hide internal directories.